#############################################################
#
#   Program: cph_model2.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 7 June 2016
#   Revisions: 
#     
#
#############################################################

format2 <- function(x){format(round(x,2),nsmall=2)}

d2$yn_aids[d2$yn_aids=="Unknown"] <- NA
d2 <- droplevels(d2)
d2$drinkcat <- cut(d2$times_drinks,c(-1,0,7,14,10000000))
cph1.dd1 <- datadist(with(d2,data.frame(patient,time,ltfu,age,male,site,modecat,yn_aids,art_cd4,rst_cd4,art2rst,yn_missed_art,su,yn_drugs,yn_alcohol,yn_harddrugs,yn_marijuana,times_drinks,drinkcat)))
options(datadist='cph1.dd1')

set.seed(20160606)
a2 <- aregImpute(~ ltfu * time + age + male + modecat + yn_aids + art_cd4 + rst_cd4 + art2rst + su + yn_missed_art + yn_alcohol + yn_drugs, n.impute=25,data=d2,nk=4)

model2.nl1<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol * yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2)
model2.nl2<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4 + rcs(art2rst,4) + yn_alcohol * yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2)
model2<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2sub<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2int<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2subint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)


##### CHECKING PH ASSUMPTION #####
# checkhaz1 <- cox.zph(model2,transform='log')
# checkhaz2 <- cox.zph(model2sub,transform='log')
# plot(checkhaz1)
# plot(checkhaz2)



## FIRST THE MODEL WITHOUT ADHERENCE
cphsum1 <- summary(model2sub,age=c(30,20),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model2sub,age=c(30,40),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model2sub,age=c(30,50),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0,yn_alcohol="No",yn_drugs="No")[c(2,4,12,14,16,18,6,8,10,20,22),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2sub <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:13],"omit")

model2pvalsub <- sapply(as.data.frame(anova(model2sub))$P,myformat4)
pval1sub <- c(model2pvalsub[1],rep("",4),model2pvalsub[3:4],rep("",4),model2pvalsub[c(5:10)],"")

## NEXT THE MODEL WITH ADHERENCE
cphsum1 <- summary(model2,age=c(30,20),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model2,age=c(30,40),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model2,age=c(30,50),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(2,10),yn_aids="No",male=0,yn_alcohol="No",yn_drugs="No")[c(2,4,12,14,16,18,6,8,10,20,22,24),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2 <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:14])

cph.labels <- c("Age","\\hspace{0.2in}20 years","\\hspace{0.2in}30 years (ref)","\\hspace{0.2in}40 years","\\hspace{0.2in}50 years","Male (vs. Female)",
                "Mode of HIV acquisition","\\hspace{0.2in}Heterosexual (ref)","\\hspace{0.2in}Homosexual","\\hspace{0.2in}IDU","\\hspace{0.2in}Other/unknown",
                "AIDS diagnosis and enrollment",
                "CD4 at ART initiation (per 100 cells/mm$^3$)","CD4 at RST administration (per 100 cells/mm$^3$)",
                "Time on cART (10 vs. 2 years)",
                "Alcohol use","Illicit drug use",#"Substance use","\\hspace{0.2in}None (ref)","\\hspace{0.2in}Alcohol only","\\hspace{0.2in}Illicit drug only","\\hspace{0.2in}Alcohol and drug",
                "Missed cART dose(s) in 7-day recall")
model2pval <- sapply(as.data.frame(anova(model2))$P,myformat4)
pval1 <- c(model2pval[1],rep("",4),model2pval[3:4],rep("",4),model2pval[c(5:11)])
cph1tex <- paste(cph.labels,cphsumlines2,pval1,cphsumlines2sub,pval1sub,sep=" & ",collapse=" \\\\ ")

model2intpval <- sapply(as.data.frame(anova(model2int))$P,myformat4)
model2subintpval <- sapply(as.data.frame(anova(model2subint))$P,myformat4)

cph1fn1 <- paste0("There is little evidence of an interaction between alcohol and drug use on the hazard of LTFU (p=",model2intpval[10],").")
cph1fn2 <- paste0("Adjusting for adherence, there is little evidence of an interaction between alcohol and drug use on the hazard of LTFU (p=",model2subintpval[10],"). Interaction terms were excluded from the models summarized above.")

model2a<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2asub<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2aint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2asubint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)


# model2b.nl<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + rcs(times_drinks,4) + yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
# model2bsub.nl<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + rcs(times_drinks,4) + yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)

model2b<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks + yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2bsub<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks + yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2bint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks * yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2bsubint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks * yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)


model2c<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat + yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2csub<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat + yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2cint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat * yn_drugs + yn_missed_art, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)
model2csubint<-fit.mult.impute(Surv(time,ltfu) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat * yn_drugs, fitter=cph, xtrans=a2, data=d2,x=TRUE,y=TRUE)



cph1sum1a <- getsumline(summary(model2a)[c(22,24),])
cph1sum1asub <- getsumline(summary(model2asub)[c(22,24),])
cph1atex <- paste(c("Marijuana use\\tnote{1}","Hard drug use"),
                  cph1sum1a,sapply(as.data.frame(anova(model2a))$P[c(10,11)],myformat4),
                  cph1sum1asub,sapply(as.data.frame(anova(model2asub))$P[c(10,11)],myformat4),sep=" & ",collapse=" \\\\ ")

cph1sum1b <- getsumline1(summary(model2b,times_drinks=c(0,7))[12,])
cph1sum1c <- getsumline(summary(model2c)[c(20,22,24),])
cph1sum1bsub <- getsumline1(summary(model2bsub,times_drinks=c(0,7))[12,])
cph1sum1csub <- getsumline(summary(model2csub)[c(20,22,24),])

cph1btex <- paste("Alcohol use (per 7 drinks)\\tnote{2}",cph1sum1b,myformat4(as.data.frame(anova(model2b))$P[9]),cph1sum1bsub,myformat4(as.data.frame(anova(model2bsub))$P[9]),sep=" & ",collapse=" \\\\ ")
cph1ctex <- paste(c("Alcohol use\\tnote{2}","\\hspace{0.2in}None (ref)","\\hspace{0.2in}1-7 drinks","\\hspace{0.2in}8-14 drinks","\\hspace{0.2in}$>$14 drinks"),
                  c("","1",cph1sum1c),c(myformat4(as.data.frame(anova(model2c))$P[9]),rep("",4)),
                  c("","1",cph1sum1csub),c(myformat4(as.data.frame(anova(model2csub))$P[9]),rep("",4)),sep=" & ",collapse=" \\\\ ")

