#############################################################
#
#   Program: cph_model3.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 8 June 2016
#   Revisions: 
#     
#
#############################################################

d3 <- droplevels(d3)
cph2.dd1 <- datadist(with(d3,data.frame(patient,time,vfailure,age,male,site,modecat,yn_aids,art_cd4,rst_cd4,art2rst,yn_missed_art,su,yn_drugs,yn_alcohol,yn_harddrugs,times_drinks,yn_marijuana,drinkcat)))
options(datadist='cph2.dd1')

set.seed(20160606)
a3 <- aregImpute(~ vfailure * time + age + male + modecat + yn_aids + art_cd4 + rst_cd4 + art2rst + su + yn_missed_art + yn_alcohol + yn_drugs, n.impute=25,data=d3,nk=4)

model3.nl1<-fit.mult.impute(Surv(time,vfailure) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3)
model3.nl2<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3)
model3<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3sub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3int<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3subint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)


##### CHECKING PH ASSUMPTION #####
# checkhaz1 <- cox.zph(model3,transform='log')
# checkhaz2 <- cox.zph(model3sub,transform='log')
# plot(checkhaz1)
# plot(checkhaz2)



## FIRST THE MODEL WITHOUT ADHERENCE
cphsum1 <- summary(model3sub,age=c(30,20),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model3sub,age=c(30,40),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model3sub,age=c(30,50),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[c(2,4,12,14,16,18,6,8,10,20,22),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2sub <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:13],"omit")

model3pvalsub <- sapply(as.data.frame(anova(model3sub))$P,myformat4)
pval1sub <- c(model3pvalsub[1],rep("",4),model3pvalsub[2:3],rep("",4),model3pvalsub[c(4:5,7,9,11,12)],"")

## NEXT THE MODEL WITH ADHERENCE
cphsum1 <- summary(model3,age=c(30,20),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model3,age=c(30,40),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model3,age=c(30,50),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[c(2,4,12,14,16,18,6,8,10,20,22,24),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2 <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:14])

cph.labels <- c("Age","\\hspace{0.2in}20 years","\\hspace{0.2in}30 years (ref)","\\hspace{0.2in}40 years","\\hspace{0.2in}50 years","Male (vs. Female)",
                "Mode of HIV acquisition","\\hspace{0.2in}Heterosexual (ref)","\\hspace{0.2in}Homosexual","\\hspace{0.2in}IDU","\\hspace{0.2in}Other/unknown",
                "AIDS diagnosis and enrollment",
                "CD4 at ART initiation (300 vs. 75 cells/mm$^3$)","CD4 at RST administration (700 vs. 350 cells/mm$^3$)",
                "Time on cART (10 vs. 2 years)",
                "Alcohol use","Illicit drug use",
                "Missed cART dose(s) in 7-day recall")
model3pval <- sapply(as.data.frame(anova(model3))$P,myformat4)
pval1 <- c(model3pval[1],rep("",4),model3pval[2:3],rep("",4),model3pval[c(4:5,7,9,11:13)])
cph2tex <- paste(cph.labels,cphsumlines2,pval1,cphsumlines2sub,pval1sub,sep=" & ",collapse=" \\\\ ")


model3pvalsubint <- sapply(as.data.frame(anova(model3subint))$P,myformat4)
model3pvalint <- sapply(as.data.frame(anova(model3int))$P,myformat4)


cph2fn1 <- paste0("There is little evidence of an interaction between alcohol and drug use on the hazard of viral failure (p=",model3pvalsubint[12],").")
cph2fn2 <- paste0("Adjusting for adherence, there is little evidence of an interaction between alcohol and drug use on the hazard of viral failure (p=",model3pvalint[12],"). Interaction terms were excluded from the models summarized above.")




model3a<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3asub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)

model3aint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3asubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)


# model3b.nl<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + rcs(times_drinks,4) + yn_drugs + yn_missed_art, fitter=cph, , xtrans=a3, data=d3,x=TRUE,y=TRUE)
# model3bsub.nl<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + rcs(times_drinks,4) + yn_drugs, fitter=cph, , xtrans=a3, data=d3,x=TRUE,y=TRUE)

model3b<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks + yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3bsub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks + yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)

model3c<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat + yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3csub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat + yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)


model3bint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks * yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3bsubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks * yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)

model3cint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat * yn_drugs + yn_missed_art, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)
model3csubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat * yn_drugs, fitter=cph, xtrans=a3, data=d3,x=TRUE,y=TRUE)

cph2sum1a <- getsumline(summary(model3a)[c(22,24),])
cph2sum1asub <- getsumline(summary(model3asub)[c(22,24),])
cph2atex <- paste(c("Marijuana use\\tnote{1}","Hard drug use"),
                  cph2sum1a,sapply(as.data.frame(anova(model3a))$P[c(12,13)],myformat4),
                  cph2sum1asub,sapply(as.data.frame(anova(model3asub))$P[c(12,13)],myformat4),sep=" & ",collapse=" \\\\ ")

cph2sum1b <- getsumline1(summary(model3b,times_drinks=c(0,7))[12,])
cph2sum1c <- getsumline(summary(model3c)[c(20,22,24),])
cph2sum1bsub <- getsumline1(summary(model3bsub,times_drinks=c(0,7))[12,])
cph2sum1csub <- getsumline(summary(model3csub)[c(20,22,24),])

cph2btex <- paste("Alcohol use (per 7 drinks)\\tnote{2}",cph2sum1b,myformat4(as.data.frame(anova(model3b))$P[11]),cph2sum1bsub,myformat4(as.data.frame(anova(model3bsub))$P[11]),sep=" & ",collapse=" \\\\ ")
cph2ctex <- paste(c("Alcohol use\\tnote{2}","\\hspace{0.2in}None (ref)","\\hspace{0.2in}1-7 drinks","\\hspace{0.2in}8-14 drinks","\\hspace{0.2in}$>$14 drinks"),
                  c("","1",cph2sum1c),c(myformat4(as.data.frame(anova(model3c))$P[11]),rep("",4)),
                  c("","1",cph2sum1csub),c(myformat4(as.data.frame(anova(model3csub))$P[11]),rep("",4)),sep=" & ",collapse=" \\\\ ")

