#############################################################
#
#   Program: cph_model4.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 10 June 2016
#   Revisions: 
#     
#
#############################################################

d4 <- droplevels(d4)
cph3.dd1 <- datadist(with(d4,data.frame(patient,time,vfailure,age,male,site,modecat,yn_aids,art_cd4,rst_cd4,art2rst,yn_missed_art,su,yn_drugs,yn_alcohol,yn_marijuana,times_drinks,yn_harddrugs,drinkcat)))
options(datadist='cph3.dd1')

set.seed(20160606)
a4 <- aregImpute(~ vfailure * time + age + male + modecat + yn_aids + art_cd4 + rst_cd4 + art2rst + su + yn_missed_art + yn_alcohol + yn_drugs, n.impute=25,data=d4,nk=4)

model4.nl1<-fit.mult.impute(Surv(time,vfailure) ~ rcs(age,4) + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4)
model4.nl2<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4)
model4<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4sub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4int<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4subint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)


##### CHECKING PH ASSUMPTION #####
# checkhaz1 <- cox.zph(model4,transform='log')
# checkhaz2 <- cox.zph(model4sub,transform='log')
# plot(checkhaz1)
# plot(checkhaz2)



## FIRST THE MODEL WITHOUT ADHERENCE
cphsum1 <- summary(model4sub,age=c(30,20),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model4sub,age=c(30,40),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model4sub,age=c(30,50),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[c(2,4,12,14,16,18,6,8,10,20,22),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2sub <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:13],"omit")

model4pvalsub <- sapply(as.data.frame(anova(model4sub))$P,myformat4)
pval1sub <- c(model4pvalsub[1],rep("",4),model4pvalsub[2:3],rep("",4),model4pvalsub[c(4:5,7,9,11,12)],"")

## NEXT THE MODEL WITH ADHERENCE
cphsum1 <- summary(model4,age=c(30,20),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum2 <- summary(model4,age=c(30,40),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[2,]
cphsum3 <- summary(model4,age=c(30,50),art_cd4=c(75,300),rst_cd4=c(350,700),art2rst=c(2,10),yn_aids="No",male=0)[c(2,4,12,14,16,18,6,8,10,20,22,24),]
cphsum <- rbind(cphsum1,cphsum2,cphsum3)
cphsumlines1 <- paste0(sapply(cphsum[,4],myformat2)," (",sapply(cphsum[,6],myformat2),", ",sapply(cphsum[,7],myformat2),")")
cphsumlines2 <- c("",cphsumlines1[1],"1",cphsumlines1[2:4],"","1",cphsumlines1[5:11],cphsumlines1[12:14])

# cph.labels <- c("Age","\\hspace{0.2in}20 years","\\hspace{0.2in}30 years (ref)","\\hspace{0.2in}40 years","\\hspace{0.2in}50 years","Male (vs. Female)",
#                 "Mode of HIV acquisition","\\hspace{0.2in}Heterosexual (ref)","\\hspace{0.2in}Homosexual","\\hspace{0.2in}IDU","\\hspace{0.2in}Other/unknown",
#                 "AIDS diagnosis and enrollment",
#                 "CD4 at ART initiation (300 vs. 75 cells/mm$^3$)","CD4 at RST administration (700 vs. 350 cells/mm$^3$)",
#                 "Time on cART (10 vs. 2 years)",
#                 "Substance use","\\hspace{0.2in}None (ref)","\\hspace{0.2in}Alcohol only","\\hspace{0.2in}Illicit drug only","\\hspace{0.2in}Alcohol and drug",
#                 "Missed cART dose(s) in 7-day recall")
model4pval <- sapply(as.data.frame(anova(model4))$P,myformat4)
pval1 <- c(model4pval[1],rep("",4),model4pval[2:3],rep("",4),model4pval[c(4:5,7,9,11:13)])
cph3tex <- paste(cph.labels,cphsumlines2,pval1,cphsumlines2sub,pval1sub,sep=" & ",collapse=" \\\\ ")


model4pvalsubint <- sapply(as.data.frame(anova(model4subint))$P,myformat4)
model4pvalint <- sapply(as.data.frame(anova(model4int))$P,myformat4)

cph3fn1 <- paste0("There is little evidence of an interaction between alcohol and drug use on the hazard of viral failure (p=",model4pvalsubint[12],").")
cph3fn2 <- paste0("Adjusting for adherence, there is little evidence of an interaction between alcohol and drug use on the hazard of viral failure (p=",model4pvalint[12],"). Interaction terms were excluded from the models summarized above.")



model4a<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4asub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol + yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4aint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_marijuana + yn_harddrugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4asubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + yn_alcohol * yn_marijuana + yn_harddrugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)


# model4b.nl<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + rcs(times_drinks,4) + yn_drugs + yn_missed_art, fitter=cph, , xtrans=a4, data=d4,x=TRUE,y=TRUE)
# model4bsub.nl<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + rcs(times_drinks,4) + yn_drugs, fitter=cph, , xtrans=a4, data=d4,x=TRUE,y=TRUE)

model4b<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks + yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4bsub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks + yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)

model4c<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat + yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4csub<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat + yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)

model4bint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks * yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4bsubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + times_drinks * yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)

model4cint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat * yn_drugs + yn_missed_art, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)
model4csubint<-fit.mult.impute(Surv(time,vfailure) ~ age + male + strat(site) + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4)  + rcs(art2rst,3) + drinkcat * yn_drugs, fitter=cph, xtrans=a4, data=d4,x=TRUE,y=TRUE)


cph3sum1a <- getsumline(summary(model4a)[c(22,24),])
cph3sum1asub <- getsumline(summary(model4asub)[c(22,24),])
cph3atex <- paste(c("Marijuana use\\tnote{1}","Hard drug use"),
                  cph3sum1a,sapply(as.data.frame(anova(model4a))$P[c(12,13)],myformat4),
                  cph3sum1asub,sapply(as.data.frame(anova(model4asub))$P[c(12,13)],myformat4),sep=" & ",collapse=" \\\\ ")

cph3sum1b <- getsumline1(summary(model4b,times_drinks=c(0,7))[12,])
cph3sum1c <- getsumline(summary(model4c)[c(20,22,24),])
cph3sum1bsub <- getsumline1(summary(model4bsub,times_drinks=c(0,7))[12,])
cph3sum1csub <- getsumline(summary(model4csub)[c(20,22,24),])

cph3btex <- paste("Alcohol use (per 7 drinks)\\tnote{2}",cph3sum1b,myformat4(as.data.frame(anova(model4b))$P[11]),cph3sum1bsub,myformat4(as.data.frame(anova(model4bsub))$P[11]),sep=" & ",collapse=" \\\\ ")
cph3ctex <- paste(c("Alcohol use\\tnote{2}","\\hspace{0.2in}None (ref)","\\hspace{0.2in}1-7 drinks","\\hspace{0.2in}8-14 drinks","\\hspace{0.2in}$>$14 drinks"),
                  c("","1",cph3sum1c),c(myformat4(as.data.frame(anova(model4c))$P[11]),rep("",4)),
                  c("","1",cph3sum1csub),c(myformat4(as.data.frame(anova(model4csub))$P[11]),rep("",4)),sep=" & ",collapse=" \\\\ ")

