#############################################################
#
#   Program: load_data.R
#  
#   Project: CCASAnet
#
#   Biostatisticians: Meridith Blevins, MS**
#                     Bryan E Shepherd, PhD
#   ** contact programmer: meridith.blevins at vanderbilt.edu
#
#   Purpose: RST2
#
#   Notes: 
#          
#   Created: 1 May 2016
#	  
#   Revisions: 
#   
#
#############################################################

library(Hmisc)

if(.Platform$OS.type == "windows") {
  baseDir <- file.path("B:", "Projects/") } else {
    baseDir <- file.path("~", "Projects/") }
setwd(baseDir)

setwd("CCASAnet/SubstanceUse/Data/")
## IDENTIFIED WHICH TABLES TO READ IN FROM DES IN MASTER PANEL_GRAPHICX.R PROGRAM

## AIDSstatus from Mark on 8/1
load("CCASAnetAIDSstatus.Rda")

## READ IN DATA FILES
readtables <- c("rst","basic","art","follow","lab_cd4","lab_rna","visit")

## CHOOSE FIRST SELECTS THE TEXT STRING OCCURING BEFORE THE SPECIFIED SEPARATER
choosefirst <- function(var,sep=".") unlist(lapply(strsplit(var,sep,fixed=TRUE),function(x) x[1]))
## DETERMINE WHICH TABLES EXIST IN '/input'
existingtables <- choosefirst(list.files("database_20160707"))
if(!all(readtables %in% existingtables)) stop(paste0("Please place the expected tables in /input folder named as specified: (",paste(readtables,collapse=", "),")"))
## READ IN ALL EXISTING TABLES
for(i in 1:length(readtables)){
  if(!is.na(readtables[i])){
     readcsv <- read.csv(paste("database_20160707/",readtables[i],".csv",sep=""),header=TRUE,stringsAsFactors = FALSE,na.strings=c(NA,""))
     names(readcsv) <- tolower(names(readcsv))
     assign(readtables[i],readcsv)
   }
}
readcsv <- NULL

setwd(paste0(baseDir,"/CCASAnet/SubstanceUse/Code/"))
source("utility_functions.R")

rst_ccasanet <- cleanup.import(rst,datevars=c('rst_d'),dateformat='%Y-%m-%d')

## Karu said to ignore mx.108
length(rst_ccasanet$patient[!(rst_ccasanet$patient %in% basic$patient)])
length(rst_ccasanet$patient[(rst_ccasanet$patient %in% basic$patient)])

## Choose the most recent RST survey
# rst_ccasanet$rst_d <- as.Date(rst_ccasanet$rst_d)
rst_ccasanet <- rst_ccasanet[!is.na(rst_ccasanet$rst_d),]
rst_ccasanet <- rst_ccasanet[order(rst_ccasanet$patient,rst_ccasanet$rst_d),]
rst_one <- rst_ccasanet[!duplicated(rst_ccasanet$patient,fromLast = TRUE),]

## Confirm the correct form was selected
rst_ccasanet[rst_ccasanet$patient=="mx.949",]
rst_one[rst_one$patient=="mx.949",]

## Yes/No stubstance use
rst_one$yn_marijuana <- ifelse(rst_one$times_marijuana>0,"Yes","No")
rst_one$yn_cocaine <- ifelse(rst_one$times_cocaine>0,"Yes","No")
rst_one$yn_crack <- ifelse(rst_one$times_crack>0,"Yes","No")
rst_one$yn_meth <- ifelse(rst_one$times_meth>0,"Yes","No")
rst_one$yn_heroin <- ifelse(rst_one$times_heroin>0,"Yes","No")
rst_one$yn_alcohol <- ifelse(rst_one$times_drinks>0,"Yes","No")
rst_one$yn_drugs <- ifelse(with(rst_one,yn_marijuana=="Yes" | yn_cocaine=="Yes" | yn_crack=="Yes" | yn_meth=="Yes" | yn_heroin=="Yes"),"Yes","No")
rst_one$yn_harddrugs <- ifelse(with(rst_one,yn_cocaine=="Yes" | yn_crack=="Yes" | yn_meth=="Yes" | yn_heroin=="Yes"),"Yes","No")
rst_one$yn_missed_art <- ifelse(rst_one$times_missed_art>0,"Yes","No")

## substance use per SAP
rst_one$su <- NA
rst_one$su[rst_one$yn_alcohol=="No" & rst_one$yn_drugs=="No"] <- 0
rst_one$su[rst_one$yn_alcohol=="Yes" & rst_one$yn_drugs=="No"] <- 1
rst_one$su[rst_one$yn_alcohol=="No" & rst_one$yn_drugs=="Yes"] <- 2
rst_one$su[rst_one$yn_alcohol=="Yes" & rst_one$yn_drugs=="Yes"] <- 3
rst_one$su <- factor(rst_one$su,levels=0:3,labels=c("None","Alcohol use only","Illicit drug use only","Alcohol and illicit drug use"))

## DETERMINE THE FIRST DATE OF ART RECEIPT FROM TBLART
art_first <- getselectdate(art_sd,patient,data=art,dateformat="%Y-%m-%d") # default type="first"

## Keep only those patients on or initiating ART at RST
## with complete adherence and substance use data
art_rst <- merge(rst_one,art_first)
rst <- art_rst[art_rst$art_sd_first_cmp <= art_rst$rst_d & !is.na(art_rst$yn_missed_art) & !is.na(art_rst$su),]

## subset data and convert dates
basic <- cleanup.import(basic[basic$patient %in% unique(art_rst$patient),],datevars=c('birth_d','enrol_d','hivdiagnosis_d','aids_d'),dateformat='%Y-%m-%d')
basic <- basic[!duplicated(basic$patient),]
art <- cleanup.import(art[art$patient %in% unique(art_rst$patient),],datevars=c('art_sd','art_ed'),dateformat='%Y-%m-%d')
follow <- cleanup.import(follow[follow$patient %in% unique(art_rst$patient),],datevars=c('death_d','drop_d','l_alive_d'),dateformat='%Y-%m-%d')
lab_cd4 <- cleanup.import(lab_cd4[lab_cd4$patient %in% unique(art_rst$patient),],datevars=c('cd4_d'),dateformat='%Y-%m-%d')
lab_cd4 <- lab_cd4[!is.na(lab_cd4$cd4_v),]
lab_cd4 <- lab_cd4[!duplicated(paste(lab_cd4$patient,lab_cd4$cd4_v)),]
lab_rna <- cleanup.import(lab_rna[lab_rna$patient %in% unique(art_rst$patient),],datevars=c('rna_d'),dateformat='%Y-%m-%d')
visit <- cleanup.import(visit[visit$patient %in% unique(art_rst$patient),],datevars=c('visit_d'),dateformat='%Y-%m-%d')

## Determine what the lower limit of detection is for this time frame is 50 (40 is most frequent)
slab_rna <- lab_rna[as.Date(lab_rna$rna_d)>=as.Date("2012-01-01"),]
table(slab_rna$rna_v)
table(slab_rna$rna_l)

## Get CD4 count for models
lab_cd4_rst_basic <- merge(merge(lab_cd4,rst,by="patient"),basic,by="patient")

rst_cd4 <- getbaseline(rst_d,cd4_d,patient,value=cd4_v,before=30*6,after=30*6,type="closest",data=lab_cd4_rst_basic,returndate=TRUE,dateformat="%Y-%m-%d")
art_cd4 <- getbaseline(art_sd_first_cmp,cd4_d,patient,value=cd4_v,before=30*6,after=30*6,type="closest",data=lab_cd4_rst_basic,returndate=TRUE,dateformat="%Y-%m-%d")
names(rst_cd4) <- c("patient","rst_cd4_d","rst_cd4")
names(art_cd4) <- c("patient","art_cd4_d","art_cd4")

## identify the database close date and assign as close_d
art_last1 <- getselectdate(art_sd,patient,data=art,dateformat="%Y-%m-%d",type="last") 
art_last2 <- getselectdate(art_ed,patient,data=art,dateformat="%Y-%m-%d",type="last") 
cd4_last <- getselectdate(cd4_d,patient,data=lab_cd4,dateformat="%Y-%m-%d",type="last") 
rna_last <- getselectdate(rna_d,patient,data=lab_rna,dateformat="%Y-%m-%d",type="last") 
vis_last <- getselectdate(visit_d,patient,data=visit,dateformat="%Y-%m-%d",type="last") 

alldates <- merge(merge(merge(merge(merge(basic[c("patient","site","enrol_d")],
                                          merge(art_last1,art_last2,all=TRUE),all=TRUE),
                                    cd4_last,all=TRUE),rna_last,all=TRUE),
                        follow[c("patient","death_d","drop_d","l_alive_d")],all=TRUE),vis_last,all=TRUE)
alldates$last_d <- apply(alldates[,3:11],1,max,na.rm=TRUE)
## could have just used follow:  table(alldates$last_d==alldates$l_alive_d)

databaseclose <- with(alldates,aggregate(list(close_d=as.Date(last_d)),list(site=site),max))
basic_rst <- merge(merge(basic,databaseclose),rst[c("patient",setdiff(names(rst),names(basic)))])

## calculate age at RST
basic_rst$age <- with(basic_rst,as.numeric(rst_d - birth_d)/365.25)
## confirmed all are 18+ at time of RST

## categorize mode of transmission
basic_rst$mode[basic_rst$mode==1] <- "Homosexual contact"
basic_rst$mode[basic_rst$mode==2] <- "Injecting drug user"
basic_rst$mode[basic_rst$mode==3] <- "Homo/Bisexual and Injecting drug user"
basic_rst$mode[basic_rst$mode==4] <- "Hemophiliac"
basic_rst$mode[basic_rst$mode==5] <- "Transfusion nonhemophilia related"
basic_rst$mode[basic_rst$mode==6] <- "Heterosexual contact"
basic_rst$mode[basic_rst$mode==7] <- "Heterosexual contact and Injecting drug user"
basic_rst$mode[basic_rst$mode==8] <- "Perinatal"
basic_rst$mode[basic_rst$mode==9] <- "Generic Sexual"
basic_rst$mode[basic_rst$mode==10] <- "Bisexual"
basic_rst$mode[basic_rst$mode==90] <- "Other (specify in mode_oth)"
basic_rst$mode[basic_rst$mode==99] <- "Unknown"

basic_rst$modecat <- basic_rst$mode
## bisexual was categorized as homosexual for men and heterosexual for women
basic_rst$modecat[basic_rst$mode=="Bisexual" & basic_rst$male==1] <- "Homosexual contact"
basic_rst$modecat[basic_rst$mode=="Bisexual" & basic_rst$male==0] <- "Heterosexual contact"
basic_rst$modecat[basic_rst$mode %in% c("Heterosexual contact and Injecting drug user","Homo/Bisexual and Injecting drug user")] <- "Injecting drug user"
basic_rst$modecat[basic_rst$mode %in% c("Unknown","Other (specify in mode_oth)","Perinatal","Transfusion nonhemophilia related","Hemophiliac","Generic Sexual")] <- "Other/unknown"

## calculate time on ART
basic_rst$art2rst <- with(basic_rst,as.numeric(rst_d - art_sd_first_cmp)/365.25)

## calculate LTFU definition 1: 2 or more HIV care visits 90 days apart in 2015.
library(data.table)
visit2015 <- visit[visit$visit_d >= as.Date("2014-05-01") & visit$visit_d <= as.Date("2015-05-01") & !is.na(visit$visit_d),]
# visit2015 <- visit[substr(visit$visit_d,1,4)==2015 & !is.na(visit$visit_d),]  
visit2015 <- data.table(visit2015, key = c("patient"))
visit2015[,visit_first:=min(visit_d),by=patient] 
visit2015[,visit_last:=max(visit_d),by=patient] 
basic_rst$retained2015 <- ifelse(basic_rst$patient %in% unique(visit2015$patient[visit2015$visit_last - visit2015$visit_first >= 90]),"Yes","Unknown")
basic_rst$retained2015[basic_rst$close_d >= as.Date("2015-05-01") & basic_rst$retained2015=="Unknown"] <- "No"

## calculate LTFU definition 2: gap in care larger than 1 year
basic_rst_follow <- merge(basic_rst,follow,all.x=TRUE)
# basic_rst_follow$ltfu <- ifelse(with(basic_rst_follow,as.numeric(close_d - l_alive_d)) > 365,"Yes","No")
# basic_rst_follow$ltfu[with(basic_rst_follow,close_d-rst_d < 365)] <- "Unknown" ## there were 188 affected, a handful that were ltfu because the l_alive_d << rst_d

## Virological failure will be defined as one of the following: (1) two consecutive values of more than 50 copies per mL; (2) a single measurement of more than 1000 copies per mL. The cutoff of 50 copies per mL is the viral load detection limit for many of the sites during much of the study period.
lab_rna <- lab_rna[!is.na(lab_rna$rna_v),]
lab_rna_rst <- merge(lab_rna,rst)
lab_rna_rst <- lab_rna_rst[order(lab_rna_rst$patient,lab_rna_rst$rna_d),]
lab_rna_rst <- lab_rna_rst[lab_rna_rst$rna_d >= lab_rna_rst$rst_d,]
lab_rna_rst$rna_v_over50 <- lab_rna_rst$rna_v > 50
lab_rna_rst$pattern <- unsplit(lapply(split(lab_rna_rst$rna_v_over50,lab_rna_rst$patient),function(x) paste(ifelse(x,"a","b"),collapse="")),lab_rna_rst$patient)
lab_rna_rst$which.pattern <- unsplit(lapply(split(lab_rna_rst$pattern,lab_rna_rst$patient),function(x) gregexpr(pattern ='aa',x)[[1]][1]),lab_rna_rst$patient)
## number each rna
lab_rna_rst$num <- ave(as.numeric(lab_rna_rst$rna_d), lab_rna_rst$patient, FUN = seq_along)
lab_rna_rst$vf1_d <- as.Date(ifelse(lab_rna_rst$num==lab_rna_rst$which.pattern,as.character(lab_rna_rst$rna_d),NA))
vf1 <- with(lab_rna_rst[!is.na(lab_rna_rst$vf1_d),],data.frame(patient,vf1_d,pattern))
## vl over 1000
lab_rna_rst$rna_v_over1000 <- lab_rna_rst$rna_v > 1000
lab_rna_rst <- lab_rna_rst[order(lab_rna_rst$patient,-lab_rna_rst$rna_v_over1000,lab_rna_rst$rna_d),]
vf2 <- lab_rna_rst[!duplicated(lab_rna_rst$patient),]
# lab_rna_rst[lab_rna_rst$patient=="br.28771",] -- check sort
# vf2[vf2$patient=="br.28771",]
vf2$vf2_d <- as.Date(ifelse(vf2$rna_v_over1000,as.character(vf2$rna_d),NA))

vf <- merge(merge(unique(with(lab_rna_rst,data.frame(patient))),with(vf2,data.frame(patient,vf1_d)),all.x=TRUE),with(vf2,data.frame(patient,vf2_d)),all.x=TRUE)
vf$vf_d <- apply(with(vf,data.frame(vf1_d,vf2_d)),1,min,na.rm=TRUE)
vf$vfailure <- ifelse(!is.na(vf$vf_d),1,0)
  
## if gap > 1 year, censor before gap
require(data.table)
lab_rna_rst <- lab_rna_rst[order(lab_rna_rst$patient,-as.numeric(lab_rna_rst$rna_d)),]
lab_rna_rst <- data.table(lab_rna_rst)
setkey(lab_rna_rst,patient)
lab_rna_rst[,diff:=c(NA,diff(rna_d)),by=patient]
lab_rna_rst$censor_d <- as.Date(ifelse(lab_rna_rst$diff < -365,as.character(lab_rna_rst$rna_d),NA))
# lab_rna_rst[148:151,] check
## choose the first gap instance
vfcensor <- with(lab_rna_rst[!is.na(lab_rna_rst$censor_d)],aggregate(list(censor_d=censor_d),list(patient=patient),min))

## to merge: rst_cd4 art_cd4
data <- merge(merge(merge(merge(merge(basic_rst_follow,
                                      rst_cd4,all.x=TRUE),
                                art_cd4,all.x=TRUE),
                          vf,all.x=TRUE),
                    vfcensor,all.x=TRUE),
              AIDSstatus,all.x=TRUE)

setwd(paste0(baseDir,"/CCASAnet/SubstanceUse/Data/"))
save(data,file="analysis.RData")
