#############################################################
#
#   Program: lrm_model1.R
#   Project: CCASAnet
#   PI:  
#   Statistican/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Notes: 
#   Created: 6 June 2016
#   Revisions: 
#     
#
#############################################################
library(rms)
data$ltfu1 <- match(data$retained2015,c("Yes","No"))-1
dieb4 <- !is.na(data$death_d) & data$death_d < as.Date("2015-05-01")
tfrb4 <- !is.na(data$drop_d) & data$drop_d < as.Date("2015-05-01") & !is.na(data$drop_rs) & data$drop_rs=="Patient transfered"
d1 <- data[!is.na(data$ltfu1) & !dieb4 & !tfrb4,]
d1$yn_aids[d1$yn_aids=="Unknown"] <- NA
d1 <- droplevels(d1)
d1$drinkcat <- cut(d1$times_drinks,c(-1,0,7,14,10000000))
dd <- datadist(with(d1,data.frame(drinkcat,age,male,site,modecat,yn_aids,art_cd4,rst_cd4,art2rst,yn_missed_art,su,yn_alcohol,yn_drugs,yn_marijuana,times_drinks,times_marijuana,yn_harddrugs)))
options(datadist='dd')


exc1n1 <- sum(is.na(data$ltfu1)) 
exc1n2 <- sum(!is.na(data$ltfu1) & dieb4)
exc1n3 <- sum(!is.na(data$ltfu1) & !dieb4 & tfrb4)


t2 <- printtable1(byvar=factor(d1$ltfu1,levels=0:1,labels=c("Retained","Not Retained")),dd=d1,inc.pval=FALSE)

set.seed(20160606)
a1 <- aregImpute(~ ltfu1 + age + male + modecat + yn_aids + art_cd4 + rst_cd4 + art2rst + su + yn_missed_art + yn_alcohol + yn_drugs, n.impute=25,data=d1,nk=4)

model1.nl1<-fit.mult.impute(ltfu1 ~ rcs(age,4) + male + site + modecat + yn_aids + rcs(art_cd4,4) + rcs(rst_cd4,4) + rcs(art2rst,4) + yn_alcohol * yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1)
model1.nl2<-fit.mult.impute(ltfu1 ~ rcs(age,4) + male + site + modecat + yn_aids + art_cd4 + rcs(rst_cd4,4) + art2rst + yn_alcohol * yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1)
model1<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1sub<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1int<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1subint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)

## FIRST THE MODEL WITHOUT ADHERENCE
lrmsum1 <- summary(model1sub,age=c(30,20),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0)[2,]
lrmsum2 <- summary(model1sub,age=c(30,40),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0)[2,]
lrmsum3 <- summary(model1sub,age=c(30,50),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0,yn_alcohol="No",yn_drugs="No")[c(2,4,12,14,16,18,20,22,24,26,28,6,8,10,30,32),]

lrmsum <- rbind(lrmsum1,lrmsum2,lrmsum3)
lrmsumlines1 <- paste0(sapply(lrmsum[,4],myformat2)," (",sapply(lrmsum[,6],myformat2),", ",sapply(lrmsum[,7],myformat2),")")
lrmsumlines2sub <- c("",lrmsumlines1[1],"1",lrmsumlines1[2:4],"","1",lrmsumlines1[5:9],"","1",lrmsumlines1[10:16],lrmsumlines1[17:18],"omit")

model1pvalsub <- sapply(as.data.frame(anova(model1sub))$P,myformat4)
pval1sub <- c(model1pvalsub[1],rep("",4),model1pvalsub[2:3],rep("",6),model1pvalsub[4],rep("",4),model1pvalsub[5:10],"")

## NEXT THE MODEL WITH ADHERENCE
lrmsum1 <- summary(model1,age=c(30,20),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0)[2,]
lrmsum2 <- summary(model1,age=c(30,40),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0)[2,]
lrmsum3 <- summary(model1,age=c(30,50),art_cd4=c(0,100),rst_cd4=c(0,100),art2rst=c(0,1),yn_aids="No",male=0,yn_alcohol="No",yn_drugs="No")[c(2,4,12,14,16,18,20,22,24,26,28,6,8,10,30,32,34),]
lrmsum <- rbind(lrmsum1,lrmsum2,lrmsum3)
lrmsumlines1 <- paste0(sapply(lrmsum[,4],myformat2)," (",sapply(lrmsum[,6],myformat2),", ",sapply(lrmsum[,7],myformat2),")")
lrmsumlines2 <- c("",lrmsumlines1[1],"1",lrmsumlines1[2:4],"","1",lrmsumlines1[5:9],"","1",lrmsumlines1[10:16],lrmsumlines1[17:19])

lrm.labels <- c("Age","\\hspace{0.2in}20 years","\\hspace{0.2in}30 years (ref)","\\hspace{0.2in}40 years","\\hspace{0.2in}50 years","Male (vs. Female)",
                "Site","\\hspace{0.2in}Brazil (ref)","\\hspace{0.2in}Argentina","\\hspace{0.2in}Chile","\\hspace{0.2in}Honduras","\\hspace{0.2in}Mexico","\\hspace{0.2in}Peru",
                "Mode of HIV acquisition","\\hspace{0.2in}Heterosexual (ref)","\\hspace{0.2in}Homosexual","\\hspace{0.2in}IDU","\\hspace{0.2in}Other/unknown",
                "AIDS diagnosis and enrollment",
                "CD4 at ART initiation (per 100 cells/mm$^3$)","CD4 at RST administration (per 100 cells/mm$^3$)",
                "Time on cART (per 1 year increase)",
                "Alcohol use","Illicit drug use",#"Substance use","\\hspace{0.2in}None (ref)","\\hspace{0.2in}Alcohol only","\\hspace{0.2in}Illicit drug only","\\hspace{0.2in}Alcohol and drug",
                "Missed cART dose(s) in 7-day recall")
model1pval <- sapply(as.data.frame(anova(model1))$P,myformat4)
pval1 <- c(model1pval[1],rep("",4),model1pval[2:3],rep("",6),model1pval[4],rep("",4),model1pval[5:11])
lrm1tex <- paste(lrm.labels,lrmsumlines2,pval1,lrmsumlines2sub,pval1sub,sep=" & ",collapse=" \\\\ ")


model1intpval <- sapply(as.data.frame(anova(model1int))$P,myformat4)
model1subintpval <- sapply(as.data.frame(anova(model1subint))$P,myformat4)

lrm1fn1 <- paste0("There is little evidence of an interaction between alcohol and drug use on the log-odds of retention (p=",model1intpval[12],").")
lrm1fn2 <- paste0("Adjusting for adherence, there is little evidence of an interaction between alcohol and drug use on the log-odds of retention (p=",model1subintpval[12],"). Interaction terms were excluded from the models summarized above.")


getsumline <- function(lrmsum) paste0(sapply(lrmsum[,4],myformat2)," (",sapply(lrmsum[,6],myformat2),", ",sapply(lrmsum[,7],myformat2),")")
getsumline1 <- function(lrmsum) paste0(sapply(lrmsum[4],myformat2)," (",sapply(lrmsum[6],myformat2),", ",sapply(lrmsum[7],myformat2),")")


######## MARIJUANA
model1a<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_marijuana + yn_harddrugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1asub<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol + yn_marijuana + yn_harddrugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1aint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_marijuana + yn_harddrugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1asubint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + yn_alcohol * yn_marijuana + yn_harddrugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
if(as.data.frame(anova(model1aint))$P[12] < 0.10) stop("interaction term 1 has changed")
if(as.data.frame(anova(model1asubint))$P[12] < 0.10) stop("interaction term 2 has changed")
lrmsum1a <- getsumline(summary(model1a)[c(32,34),])
lrmsum1asub <- getsumline(summary(model1asub)[c(32,34),])
lrm1atex <- paste(c("Marijuana use\\tnote{1}","Hard drug use"),
                  lrmsum1a,sapply(as.data.frame(anova(model1a))$P[c(10,11)],myformat4),
                  lrmsum1asub,sapply(as.data.frame(anova(model1asub))$P[c(10,11)],myformat4),
                  sep=" & ",collapse=" \\\\ ")


######## DOSE RESPONSE ALCOHOL
# model1b<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + rcs(times_drinks,5) + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
# model1b<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + rcs(times_drinks,4) + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1b<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1c<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1bint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks * yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1cint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat * yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
if(as.data.frame(anova(model1bint))$P[12] < 0.10) stop("interaction term 3 has changed")
if(as.data.frame(anova(model1cint))$P[12] < 0.10) stop("interaction term 4 has changed")

# model1b<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks + yn_drugs + yn_missed_art, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
# plot(Predict(model1b,times_drinks),xlim=c(0,10))
# plot(Predict(model1b,times_drinks)
model1bsub<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks + yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1csub<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat + yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1bsubint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + times_drinks * yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
model1csubint<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + drinkcat * yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
if(as.data.frame(anova(model1bsubint))$P[12] < 0.10) stop("interaction term 5 has changed")
if(as.data.frame(anova(model1csubint))$P[12] < 0.10) stop("interaction term 6 has changed")
# model1bsub<-fit.mult.impute(ltfu1 ~ age + male + site + modecat + yn_aids + art_cd4 + rst_cd4  + art2rst + rcs(times_drinks,4) + yn_drugs, fitter=lrm, xtrans=a1, data=d1,x=TRUE,y=TRUE)
# plot(Predict(model1bsub,times_drinks))

lrmsum1b <- getsumline1(summary(model1b,times_drinks=c(0,7))[12,])
lrmsum1c <- getsumline(summary(model1c)[c(30,32,34),])
lrmsum1bsub <- getsumline1(summary(model1bsub,times_drinks=c(0,7))[12,])
lrmsum1csub <- getsumline(summary(model1csub)[c(30,32,34),])

lrm1btex <- paste("Alcohol use (per 7 drinks)\\tnote{2}",lrmsum1b,myformat4(as.data.frame(anova(model1b))$P[9]),lrmsum1bsub,myformat4(as.data.frame(anova(model1bsub))$P[9]),sep=" & ",collapse=" \\\\ ")
lrm1ctex <- paste(c("Alcohol use\\tnote{2}","\\hspace{0.2in}None (ref)","\\hspace{0.2in}1-7 drinks","\\hspace{0.2in}8-14 drinks","\\hspace{0.2in}$>$14 drinks"),
                  c("","1",lrmsum1c),c(myformat4(as.data.frame(anova(model1c))$P[9]),rep("",4)),
                  c("","1",lrmsum1csub),c(myformat4(as.data.frame(anova(model1csub))$P[9]),rep("",4)),sep=" & ",collapse=" \\\\ ")

# histogram(~times_drinks | yn_drugs,data=data)
# histogram(~times_drinks | yn_drugs,data=data[data$times_drinks>0,])
# knots model1b$Design$parms$times_drinks