#############################################################
#
#   Program: mortality.R
#   Project: CCASAnet
#   PI:  Meridith Blevins
#   Statistican/Programmer: Meridith Blevins, MS
#   Purpose: RST-2
#   Notes: 
#   Created: 10 June 2016
#   Revisions: 
#     
#
#############################################################
d5 <- d2

d5$rst2death <- as.numeric(d5$rst2death)
d5$time <- ifelse(d5$death==1,d5$rst2death,d5$rst2ltfu)

cph4.dd1 <- datadist(with(d5,data.frame(patient,time,vfailure,age,male,site,modecat,yn_aids,art_cd4,rst_cd4,art2rst,yn_missed_art,su,yn_alcohol)))
options(datadist='cph4.dd1')

S<-Surv(d5$time,d5$death)
S.1<-Surv(d5$time[d5$yn_alcohol=="No"],d5$death[d5$yn_alcohol=="No"])
S.2<-Surv(d5$time[d5$yn_alcohol=="Yes"],d5$death[d5$yn_alcohol=="Yes"])
S.pval <- as.data.frame(anova(with(d5,cph(Surv(time,death) ~ yn_alcohol), x=TRUE, y=TRUE)))$P[1]


pdf("graphics/kaplan-meier-mortality.pdf",width=4,height=4, bg="transparent")
par(mar=c(4,3.2,2.4,.7)) # The default is ‘c(5, 4, 4, 2) + 0.1’.
par(mgp=c(2,1,0))
plot(survfit(S.2~1),xlab="Time from RST administration (months)",ylab="Probability of Death",axes=FALSE,conf.int=FALSE,mark.time=FALSE,
     xmax=912.5,fun="event",lty=4,lwd=2.5,col=mypalette[2],ylim=c(0,0.03),xlim=c(0,547.5),xaxs = "i", yaxs = "i")
box()
axis(side=2)                                                                         
axis(side=1,at=(730*c(0,.25,.5,.75,1,1.25)),labels=c(0,6,12,18,24,30))
lines(survfit(S.1~1),lty=1,lwd=2.5,fun="event",mark.time=FALSE,xmax=912.5,col=mypalette[1],conf.int = FALSE)
lines(survfit(S~1),lty=1,lwd=3,fun="event",mark.time=FALSE,xmax=912.5,col=1,conf.int = FALSE)
legend("topleft",c("No alcohol use","Alcohol use","Overall"),
       col=c(mypalette[1:2],1),lty=c(1,4,1),
       lwd=c(2.5,2.5,3),bty="n",cex=.75)
legend("bottomright",c("Log-rank test:",paste("p=",myformat4(S.pval),sep="")),
       ,bty="n",cex=.7)
dev.off()

myper2.0 <- function(x){
  y <- paste(format(round(100*x,1),nsmall=1),"\\%",sep="")
  return(y)
}

getmortest <- function(S,itime=c(180,365,540),col2=FALSE){
  S.sum1 <- summary(survfit(S~1),times=itime)
  column2 <- paste(sapply(1-S.sum1$surv,myper2.0)," (",sapply(1-S.sum1$upper,myper2.0),", ",sapply(1-S.sum1$lower,myper2.0),")",sep="")
  S.sum2 <- paste(paste(S.sum1$time,"days"),column2,sep=" & ")
  if(col2) return(column2)
  if(!col2) return(S.sum2)
}


Stex <- paste(paste(getmortest(S.1,col2=FALSE),
                    getmortest(S,col2=TRUE),
                    getmortest(S.2,col2=TRUE),sep=" & "),collapse=" \\\\ ")

