#############################################################
#
#   Program: run_cum_inc.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 8 June 2016
#   Revisions: 
#     
#
#############################################################
## IMPUTING DATES FOR NOW
data$l_alive_d[data$l_alive_d<data$rst_d] <- data$rst_d[data$l_alive_d<data$rst_d]
data$death_d[!is.na(data$death_d) & data$death_d<data$rst_d] <- data$rst_d[!is.na(data$death_d) & data$death_d<data$rst_d]
data$drop_d[!is.na(data$drop_d) & data$drop_d<data$rst_d] <- data$rst_d[!is.na(data$drop_d) & data$drop_d<data$rst_d]

d2 <- data
d2$rst2close <- d2$close_d - d2$rst_d
d2$transfer_d <- d2$drop_d
d2$transfer_d[data$drop_rs!="Patient transfered"] <- NA
d2$rst2tfer <- d2$transfer_d - d2$rst_d
d2$rst2ltfu <- d2$l_alive_d - d2$rst_d
d2$rst2death <- d2$death_d - d2$rst_d

# querydates <- with(d2[(d2$rst2ltfu<0 & !is.na(d2$l_alive_d)),],data.frame(patient,site,rst_d,death_d,l_alive_d,drop_d))
# write.csv(querydates,paste0(baseDir,"CCASAnet/SubstanceUse/Output/query_dates.csv"),na="",row.names=FALSE)

## LTFU definition is no contact in 365 days from close
d2$ltfu <- ifelse(d2$rst2close - d2$rst2ltfu >= 365 & d2$rst2close>=365,1,0) 
d2$ltfu[!is.na(d2$rst2tfer) & d2$rst2tfer<=d2$rst2ltfu] <- 0 ## remove transfers from this
## LTFU during the first year after RST
d2$ltfu365 <- ifelse(d2$rst2ltfu<=365 & d2$rst2close - d2$rst2ltfu >= 365 & d2$rst2close>=365,1,0) 
d2$ltfu365[!is.na(d2$rst2tfer) & d2$rst2tfer<=d2$rst2ltfu] <- 0 ## remove transfers from this

d2$death <- ifelse(!is.na(d2$rst2death),1,0)
d2$death365 <- ifelse(!is.na(d2$rst2death) & d2$rst2death<=365,1,0)

d2$ltfu[d2$death==1 & d2$rst2death <= d2$rst2ltfu] <- 0  # by definition rst2death=rst2ltfu
d2$ltfu365[d2$death365==1] <- 0
d2$deathltfu <- ifelse(d2$death==1 | d2$ltfu==1,1,0)
d2$deathltfu365 <- ifelse(d2$death365==1 | d2$ltfu365==1,1,0)

d2$time365 <- ifelse(d2$death365==1,d2$rst2death,d2$rst2ltfu)
d2$time365[d2$time365 > 365] <- 365

## sometimes ltfu<haart, but that wouldn't make sense, so we ignore that case
d2$incevent <- 1*d2$ltfu + 2*(d2$death) 
d2$time <- ifelse(d2$death==1,d2$rst2death,d2$rst2ltfu)
## add 1 for all events that occurred at time zero
d2$time[d2$time==0] <- 1

# d2$incevent[d2$time>56] <- 0
# d2$time[d2$time>56] <- 56.25

source("cum_inc.R")

SU<-getltfucmprsk(d2$incevent,d2$time)
SU.1<-getltfucmprsk(d2$incevent,d2$time,subset=(d2$su=="None"))
SU.2<-getltfucmprsk(d2$incevent,d2$time,subset=(d2$su=="Alcohol use only"))
SU.3<-getltfucmprsk(d2$incevent,d2$time,subset=(d2$su=="Illicit drug use only"))
SU.4<-getltfucmprsk(d2$incevent,d2$time,subset=(d2$su=="Alcohol and illicit drug use"))
SU.pval <- testltfucmprsk(d2$incevent,d2$time,group=d2$su)$inc$Tests[1,2]


SU.1sum <- getcumincest(itime=c(180,365,540),inc=SU.1)
SU.2sum <- getcumincest(itime=c(180,365,540),inc=SU.2,col2=TRUE)
SU.3sum <- getcumincest(itime=c(180,365,540),inc=SU.3)
SU.4sum <- getcumincest(itime=c(180,365,540),inc=SU.4,col2=TRUE)
SU.sum <- getcumincest(itime=c(180,365,540),inc=SU,col2=TRUE)

# SUtex <- paste(paste(SU.1sum,SU.2sum,SU.3sum,SU.4sum,SU.sum,sep=" & "),collapse=" \\\\ ")
SUtex1 <- paste(paste(SU.1sum,SU.2sum,sep=" & "),collapse=" \\\\ ")
SUtex2 <- paste(paste(SU.3sum,SU.4sum,SU.sum,sep=" & "),collapse=" \\\\ ")

library(wesanderson)
mypalette <- wes_palette("Darjeeling")[c(1:2,4:5)]

pdf("graphics/cum-inc-ltfu.pdf",width=4,height=4, bg="transparent")
par(mar=c(4,3.2,2.4,.7)) # The default is ‘c(5, 4, 4, 2) + 0.1’.
par(mgp=c(2,1,0))
plot(SU.2$incplot,xlab="Time from RST administration (months)",ylab="Cumulative incidence of LTFU",xlim=c(0,547.5),ylim=c(0,0.25),xaxs = "i", yaxs = "i",axes=FALSE,col=0)
box()
axis(side=2)                                                                         
axis(side=1,at=(730*c(0,.25,.5,.75,1,1.25)),labels=c(0,6,12,18,24,30))
lines(SU.1$incplot,lty=1,lwd=2.5,col=mypalette[1])
lines(SU.2$incplot,lty=4,lwd=2.5,col=mypalette[2])
lines(SU.3$incplot,lty=6,lwd=2.5,col=mypalette[3])
lines(SU.4$incplot,lty=5,lwd=2.5,col=mypalette[4])
lines(SU$incplot,lty=1,lwd=3,col=1)
legend("topleft",c(levels(d2$su),"Overall"),
       col=c(mypalette,1),lty=c(1,4,6,5,1),
       lwd=c(2.5,2.5,2.5,2.5,3),bty="n",cex=.75)
legend("bottomright",c("Gray test:",paste("p",gsub("$","",myformat4(SU.pval),fixed=TRUE),sep="")),
       ,bty="n",cex=.7)
dev.off()

