#############################################################
#
#   Program: table1.R
#   Project: IeDEA TB project 
#   PI:  Muktar Aliyu
#   Statistican/Programmer: Meridith Blevins, MS
#   Purpose: analyze Nigeria R01 study characteristics
#   Notes: 
#   Created: 10 April 2015
#   Revisions: 
#     
#
#############################################################
## ASSIGN ALCOHOL CATEGORY
data$alcoholcat <- cut(data$times_drinks,c(-1,0,3,100000))
levels(data$alcoholcat) <- c("No drinks","1-3 drinks","$>$3 drinks")
## ASSIGN AGE GROUP
data$agecat <- cut(floor(data$age),c(-1,29,39,49,100000))
levels(data$agecat) <- c("18-29 years","90-39 years","40-49 years","$\\geq$50 years")
## ASSIGN CD4 CATEGORY
data$art_cd4cat <- cut(data$art_cd4,c(-1,349,100000))
levels(data$art_cd4cat) <- c("$<$350 cells/mm$^3$","$\\geq$350 cells/mm$^3$")
data$rst_cd4cat <- cut(data$rst_cd4,c(-1,349,100000))
levels(data$rst_cd4cat) <- c("$<$350 cells/mm$^3$","$\\geq$350 cells/mm$^3$")
## AIDS STATUS
data$yn_aids <- match(data$preARTAIDS.all,c("not AIDS","AIDS","Unknown"))
data$yn_aids <- factor(data$yn_aids,levels=1:3,labels=c("No","Yes","Unknown"))

# byvar <- factor(data$ltfu,levels=c("No","Yes","Unknown"))
# inc.pval <- TRUE
printtable1 <- function(byvar,dd,inc.pval=TRUE,excludeline=NULL){
  line1 <- getnp1line(var=ifelse(dd$male==0,1,NA),by=byvar,rowlabel="Female",inc.pval=inc.pval,indent=FALSE)
  line2 <- tail(getmedtex(var=dd$age,by=byvar,label="Age (years), median (IQR)",digits=0,inc.pval=inc.pval,miss.label=FALSE),1)
  line3 <- tail(getnptex(var=dd$agecat,by=byvar,label="Age group",inc.pval=inc.pval),1)
  line4 <- tail(getnptex(var=sapply(dd$site,simpleCap),by=byvar,label="Site",inc.pval=inc.pval),1)
  line5 <- tail(getnptex(var=dd$modecat,by=byvar,label="HIV transmission mode",inc.pval=inc.pval),1)
  line6 <- tail(getmedtex(var=dd$art_cd4,by=byvar,label="CD4 count at ART initiation, median (IQR)",digits=0,inc.pval=inc.pval,miss.label=FALSE),1)
  line7 <- getnptex(var=dd$art_cd4cat,by=byvar,label="CD4 count at ART initiation",inc.pval=inc.pval)$line
  line8 <- tail(getmedtex(var=dd$rst_cd4,by=byvar,label="CD4 count at RST administration, median (IQR)",digits=0,inc.pval=inc.pval,miss.label=FALSE),1)
  line9 <- getnptex(var=dd$rst_cd4cat,by=byvar,label="CD4 count at RST administration",inc.pval=inc.pval)$line
  line10 <- tail(getnptex(var=dd$yn_aids,by=byvar,label="pre-ART AIDS status",inc.pval=inc.pval),1)
  line11 <- tail(getmedtex(var=dd$art2rst,by=byvar,label="ART initiation to RST administration (years), median (IQR)",digits=0,inc.pval=inc.pval,miss.label=FALSE),1)
  line12 <- tail(getnptex(var=dd$yn_missed_art,by=byvar,label="Missed ART dose in 7-day recall",inc.pval=inc.pval),1)
  line13 <- tail(getnptex(var=dd$alcoholcat,by=byvar,label="Alcohol",inc.pval=inc.pval),1)
  line14 <- tail(getnptex(var=dd$yn_marijuana,by=byvar,label="Marijuana",inc.pval=inc.pval),1)
  line15 <- tail(getnptex(var=dd$yn_cocaine,by=byvar,label="Cocaine",inc.pval=inc.pval),1)
  line16 <- tail(getnptex(var=dd$yn_crack,by=byvar,label="Crack",inc.pval=inc.pval),1)
  line17 <- tail(getnptex(var=dd$yn_heroin,by=byvar,label="Heroin",inc.pval=inc.pval),1)
  line18 <- tail(getnptex(var=dd$yn_drugs,by=byvar,label="Any illicit drug",inc.pval=inc.pval),1)
  line19 <- tail(getnptex(var=dd$su,by=byvar,label="Substance use",inc.pval=inc.pval),1)
  
  table1 <- paste(sapply(paste0("line",setdiff(1:19,excludeline)),get,envir=environment()),collapse=" \\\\ ")
  table1head <- printheader(table(byvar),pval=inc.pval)
  return(list(table=table1,header=table1head))
}
t1 <- printtable1(byvar=as.factor(sapply(data$site,simpleCap)),dd=data,excludeline=4)

t2 <- printtable1(byvar=data$su,dd=data,excludeline=19)







