#############################################################
#
#   Program: vfailure_cum_inc.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 8 June 2016
#   Revisions: 
#     
#
#############################################################

## exclude those with NO viral load data
d3 <- d2[!is.na(d2$vfailure),]
d3$vf_d <- as.Date(d3$vf_d)
d3$rst2vf <- as.Date(d3$vf_d) - d3$rst_d

d3$death <- ifelse(!is.na(d3$rst2death) & d3$rst2death < d3$rst2vf & !is.na(d3$rst2vf),1,0)

d3$incevent <- 1*d3$vfailure + 2*(d3$death) 
d3$time <- ifelse(d3$death==1,d3$rst2death,d3$rst2vf)
d3$time[is.na(d3$time)] <- d3$rst2ltfu[is.na(d3$time)]
## add 1 for all events that occurred at time zero
d3$time[d3$time==0] <- 1

VF1<-getltfucmprsk(d3$incevent,d3$time)
VF1.1<-getltfucmprsk(d3$incevent,d3$time,subset=(d3$su=="None"))
VF1.2<-getltfucmprsk(d3$incevent,d3$time,subset=(d3$su=="Alcohol use only"))
VF1.3<-getltfucmprsk(d3$incevent,d3$time,subset=(d3$su=="Illicit drug use only"))
VF1.4<-getltfucmprsk(d3$incevent,d3$time,subset=(d3$su=="Alcohol and illicit drug use"))
VF1.pval <- testltfucmprsk(d3$incevent,d3$time,group=d3$su)$inc$Tests[1,2]


VF1.1sum <- getcumincest(itime=c(180,365,540),inc=VF1.1)
VF1.2sum <- getcumincest(itime=c(180,365,540),inc=VF1.2,col2=TRUE)
VF1.3sum <- getcumincest(itime=c(180,365,540),inc=VF1.3)
VF1.4sum <- getcumincest(itime=c(180,365,540),inc=VF1.4,col2=TRUE)
VF1.sum <- getcumincest(itime=c(180,365,540),inc=VF1,col2=TRUE)

VF1tex <- paste(paste(VF1.1sum,VF1.2sum,VF1.3sum,VF1.4sum,VF1.sum,sep=" & "),collapse=" \\\\ ")
VFtex1 <- paste(paste(VF1.1sum,VF1.2sum,sep=" & "),collapse=" \\\\ ")
VFtex2 <- paste(paste(VF1.3sum,VF1.4sum,VF1.sum,sep=" & "),collapse=" \\\\ ")


pdf("graphics/cum-inc-vf1.pdf",width=4,height=4, bg="transparent")
par(mar=c(4,3.2,2.4,.7)) # The default is c(5, 4, 4, 2) + 0.1.
par(mgp=c(2,1,0))
plot(VF1.2$incplot,xlab="Time from RST administration (months)",ylab="Cumulative incidence of virological failure",xlim=c(0,547.5),ylim=c(0,0.23),xaxs = "i", yaxs = "i",axes=FALSE,col=0)
box()
axis(side=2)                                                                         
axis(side=1,at=(730*c(0,.25,.5,.75,1,1.25)),labels=c(0,6,12,18,24,30))
lines(VF1.1$incplot,lty=1,lwd=2.5,col=mypalette[1])
lines(VF1.2$incplot,lty=4,lwd=2.5,col=mypalette[2])
lines(VF1.3$incplot,lty=6,lwd=2.5,col=mypalette[3])
lines(VF1.4$incplot,lty=5,lwd=2.5,col=mypalette[4])
lines(VF1$incplot,lty=1,lwd=3,col=1)
legend("topleft",c(levels(d3$su),"Overall"),
       col=c(mypalette,1),lty=c(1,4,6,5,1),
       lwd=c(2.5,2.5,2.5,2.5,3),bty="n",cex=.75)
legend("bottomright",c("Gray test:",paste("p=",gsub("$","",myformat4(VF1.pval),fixed=TRUE),sep="")),
       ,bty="n",cex=.7)
dev.off()

