#############################################################
#
#   Program: vfailure_cum_inc.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: 
#   Created: 8 June 2016
#   Revisions: 
#     
#
#############################################################

## censor those with 1 year gaps
d4 <- d3
d4$rst2censor <- as.Date(d4$censor_d) - d4$rst_d
## change viral failure flag to 0 for those cases that have gap larger than 1 year occurring before instance of viral failure
exc4n1 <- sum(d4$rst2censor < d4$rst2vf & !is.na(d4$rst2censor) & !is.na(d4$rst2vf))
d4$vfailure[d4$rst2censor < d4$rst2vf & !is.na(d4$rst2censor) & !is.na(d4$rst2vf)] <- 0
d4$incevent <- 1*d4$vfailure + 2*(d4$death) 
d4$time <- ifelse(d4$death==1,d4$rst2death,d4$rst2vf)
d4$time[is.na(d4$time)] <- d4$rst2ltfu[is.na(d4$time)]
## here we censor those patients who have a gap larger than 1 year
d4$incevent[d4$time > d4$rst2censor & !is.na(d4$rst2censor)] <- 0 ## these were already all 0, no deaths, but just in case data changes...
exc4n2 <- sum(d4$time > d4$rst2censor & !is.na(d4$rst2censor))
d4$time[d4$time > d4$rst2censor & !is.na(d4$rst2censor)] <- d4$rst2censor[d4$time > d4$rst2censor & !is.na(d4$rst2censor)]
## add 1 day for all events that occurred at time zero
d4$time[d4$time==0] <- 1

VF2<-getltfucmprsk(d4$incevent,d4$time)
VF2.1<-getltfucmprsk(d4$incevent,d4$time,subset=(d4$su=="None"))
VF2.2<-getltfucmprsk(d4$incevent,d4$time,subset=(d4$su=="Alcohol use only"))
VF2.3<-getltfucmprsk(d4$incevent,d4$time,subset=(d4$su=="Illicit drug use only"))
VF2.4<-getltfucmprsk(d4$incevent,d4$time,subset=(d4$su=="Alcohol and illicit drug use"))
VF2.pval <- testltfucmprsk(d4$incevent,d4$time,group=d4$su)$inc$Tests[1,2]


VF2.1sum <- getcumincest(itime=c(180,365,540),inc=VF2.1)
VF2.2sum <- getcumincest(itime=c(180,365,540),inc=VF2.2,col2=TRUE)
VF2.3sum <- getcumincest(itime=c(180,365,540),inc=VF2.3)
VF2.4sum <- getcumincest(itime=c(180,365,540),inc=VF2.4,col2=TRUE)
VF2.sum <- getcumincest(itime=c(180,365,540),inc=VF2,col2=TRUE)

VF2tex <- paste(paste(VF2.1sum,VF2.2sum,VF2.3sum,VF2.4sum,VF2.sum,sep=" & "),collapse=" \\\\ ")
VF2tex1 <- paste(paste(VF2.1sum,VF2.2sum,sep=" & "),collapse=" \\\\ ")
VF2tex2 <- paste(paste(VF2.3sum,VF2.4sum,VF2.sum,sep=" & "),collapse=" \\\\ ")


pdf("graphics/cum-inc-VF2.pdf",width=4,height=4, bg="transparent")
par(mar=c(4,3.2,2.4,.7)) # The default is ‘c(5, 4, 4, 2) + 0.1’.
par(mgp=c(2,1,0))
plot(VF2.2$incplot,xlab="Time from RST administration (months)",ylab="Cumulative incidence of virological failure",xlim=c(0,547.5),ylim=c(0,0.23),xaxs = "i", yaxs = "i",axes=FALSE,col=0)
box()
axis(side=2)                                                                         
axis(side=1,at=(730*c(0,.25,.5,.75,1,1.25)),labels=c(0,6,12,18,24,30))
lines(VF2.1$incplot,lty=1,lwd=2.5,col=mypalette[1])
lines(VF2.2$incplot,lty=4,lwd=2.5,col=mypalette[2])
lines(VF2.3$incplot,lty=6,lwd=2.5,col=mypalette[3])
lines(VF2.4$incplot,lty=5,lwd=2.5,col=mypalette[4])
lines(VF2$incplot,lty=1,lwd=3,col=1)
legend("topleft",c(levels(d4$su),"Overall"),
       col=c(mypalette,1),lty=c(1,4,6,5,1),
       lwd=c(2.5,2.5,2.5,2.5,3),bty="n",cex=.75)
legend("bottomright",c("Gray test:",paste("p=",gsub("$","",myformat4(VF2.pval),fixed=TRUE),sep="")),
       ,bty="n",cex=.7)
dev.off()

